@@ -1,5 +1,5 @@
 from TB2J_OpenMX.ffiparser import OpenmxWrapper
-from TB2J.exchange import ExchangeNCL
+from TB2J.exchange import ExchangeNCL, ExchangeCL
 import os
 
 
@@ -15,14 +15,16 @@ def gen_exchange(path,
                  use_cache=False,
                  description=None):
     tbmodel=OpenmxWrapper(path, prefix)
-    #if tbmodel.non_collinear:
-    if True:
-        print("Starting to calculate exchange.")
-        description=f"""Using OpenMX data: 
-  path: {os.path.abspath(path)}
-  prefix: {prefix}
- """
-        exchange = ExchangeNCL(
+    if tbmodel.non_collinear:
+        Exchange=ExchangeNCL
+    else:
+        Exchange=ExchangeCL
+    print("Starting to calculate exchange.")
+    description=f"""Using OpenMX data: 
+path: {os.path.abspath(path)}
+prefix: {prefix}
+"""
+    exchange = Exchange(
             tbmodels=tbmodel,
             atoms=tbmodel.atoms,
             basis=tbmodel.basis,
@@ -36,9 +38,9 @@ def gen_exchange(path,
             Rcut=Rcut,
             use_cache=use_cache,
             description=description)
-        exchange.run()
-        print("\n")
-        print("All calculation finsihed. The results are in TB2J_results directory.")
+    exchange.run()
+    print("\n")
+    print("All calculation finsihed. The results are in TB2J_results directory.")
 
 if __name__=='__main__':
     gen_exchange(
